#line 2 "qc-lex.c"

#line 4 "qc-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer qc_yy_create_buffer
#define yy_delete_buffer qc_yy_delete_buffer
#define yy_flex_debug qc_yy_flex_debug
#define yy_init_buffer qc_yy_init_buffer
#define yy_flush_buffer qc_yy_flush_buffer
#define yy_load_buffer_state qc_yy_load_buffer_state
#define yy_switch_to_buffer qc_yy_switch_to_buffer
#define yyin qc_yyin
#define yyleng qc_yyleng
#define yylex qc_yylex
#define yylineno qc_yylineno
#define yyout qc_yyout
#define yyrestart qc_yyrestart
#define yytext qc_yytext
#define yywrap qc_yywrap
#define yyalloc qc_yyalloc
#define yyrealloc qc_yyrealloc
#define yyfree qc_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE qc_yyrestart(qc_yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int qc_yyleng;

extern FILE *qc_yyin, *qc_yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up qc_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up qc_yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via qc_yyrestart()), so that the user can continue scanning by
	 * just pointing qc_yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when qc_yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int qc_yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow qc_yywrap()'s to do buffer switches
 * instead of setting up a fresh qc_yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void qc_yyrestart (FILE *input_file  );
void qc_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE qc_yy_create_buffer (FILE *file,int size  );
void qc_yy_delete_buffer (YY_BUFFER_STATE b  );
void qc_yy_flush_buffer (YY_BUFFER_STATE b  );
void qc_yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void qc_yypop_buffer_state (void );

static void qc_yyensure_buffer_stack (void );
static void qc_yy_load_buffer_state (void );
static void qc_yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER qc_yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE qc_yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE qc_yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE qc_yy_scan_bytes (yyconst char *bytes,int len  );

void *qc_yyalloc (yy_size_t  );
void *qc_yyrealloc (void *,yy_size_t  );
void qc_yyfree (void *  );

#define yy_new_buffer qc_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        qc_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            qc_yy_create_buffer(qc_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        qc_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            qc_yy_create_buffer(qc_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *qc_yyin = (FILE *) 0, *qc_yyout = (FILE *) 0;

typedef int yy_state_type;

extern int qc_yylineno;

int qc_yylineno = 1;

extern char *qc_yytext;
#define yytext_ptr qc_yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up qc_yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	qc_yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 44
#define YY_END_OF_BUFFER 45
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[188] =
    {   0,
       42,   42,   42,   42,   38,   42,   38,   42,   42,   42,
       42,   42,   42,   42,   45,   43,   44,   42,   43,   44,
       41,   44,   43,   44,   22,   43,   44,   43,   44,   22,
       43,   44,   43,   44,   22,   43,   44,   22,   43,   44,
       43,   44,   22,   43,   44,   22,   43,   44,   22,   43,
       44,   22,   43,   44,   10,   11,   43,   44,   10,   11,
       43,   44,   32,   43,   44,   22,   43,   44,   33,   43,
       44,   15,   43,   44,   12,   43,   44,   22,   43,   44,
       42,   43,   44,   22,   43,   44,   37,   43,   44,   38,
       43,   44,   38,   42,   43,   44,   43,   44,    5,   43,

       44,    5,   42,   43,   44,    4,   41,   44,    5,   43,
       44,    5,   43,   44,    5,   43,   44,   40,   43,   44,
       42,   41,   29,   14,   36,   19,   26,   18,   34,   35,
       11,    1,    6,   11,   10,   11,   10,   11,   10,   24,
       30,   28,   31,   25,   13,   12,   27,   42,   37,   38,
       38,   42,   39,    4,   41,    3,    2,   40,   36,   18,
       23,    6,   11,   10,   11,   10,   20,   21,   13,   37,
       36,   10,   10,   10,   10,   37,   36,   10,   10,   10,
       16,   18,    7,    9,   17,   18,    8
    } ;

static yyconst flex_int16_t yy_accept[203] =
    {   0,
        1,    2,    3,    4,    5,    7,    9,   10,   11,   12,
       13,   14,   15,   16,   18,   21,   23,   25,   28,   30,
       33,   35,   38,   41,   43,   46,   49,   52,   55,   59,
       63,   66,   69,   72,   75,   78,   81,   84,   87,   90,
       93,   97,   99,  102,  106,  109,  112,  115,  118,  121,
      122,  123,  123,  124,  124,  125,  125,  125,  126,  127,
      128,  128,  128,  129,  129,  129,  129,  129,  130,  131,
      131,  132,  133,  134,  135,  137,  139,  139,  139,  140,
      140,  141,  142,  143,  144,  145,  146,  147,  148,  149,
      149,  149,  149,  149,  149,  150,  151,  153,  153,  154,

      154,  156,  156,  157,  158,  159,  159,  160,  160,  160,
      160,  160,  160,  161,  161,  161,  161,  162,  163,  164,
      165,  165,  166,  167,  168,  169,  170,  170,  170,  170,
      170,  171,  172,  172,  172,  172,  172,  172,  172,  172,
      173,  174,  175,  176,  176,  176,  176,  177,  178,  178,
      178,  178,  178,  179,  179,  179,  179,  179,  179,  179,
      179,  179,  179,  180,  181,  181,  181,  181,  181,  181,
      181,  181,  183,  183,  183,  183,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  185,  185,  185,  187,
      187,  187,  187,  187,  187,  187,  187,  187,  187,  187,

      188,  188
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    8,    9,   10,   11,   12,
       12,   13,   14,   12,   15,   16,   17,   18,   19,   20,
       20,   20,   20,   20,   20,   21,   21,   12,   12,   22,
       23,   24,   12,   25,   26,   27,   26,   26,   28,   26,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   30,   29,   29,   31,   29,   29,
       12,   32,   12,    9,   29,    1,   33,   27,   26,   26,

       34,   26,   35,   29,   36,   29,   29,   37,   38,   39,
       29,   40,   29,   41,   29,   29,   30,   29,   29,   31,
       29,   29,   12,   42,   12,   12,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[43] =
    {   0,
        1,    2,    3,    4,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    5,    1,    6,    6,    6,
        6,    1,    1,    1,    1,    7,    7,    7,    8,    8,
        8,    1,    7,    7,    8,    8,    8,    8,    8,    8,
        8,    1
    } ;

static yyconst flex_int16_t yy_base[226] =
    {   0,
        0,   41,   48,    0,   42,   89,   88,    0,   93,   96,
      104,    0,  529,  861,  513,  861,   98,  491,  114,  861,
      511,  488,  126,  148,   89,  132,  154,  135,  165,   77,
      131,  485,  133,    0,    0,  137,  169,  163,  491,    0,
      494,  145,  861,  493,  861,  184,  473,  476,    0,  479,
      861,  186,  861,  172,  861,  474,  474,  459,  861,  861,
      150,  203,  861,  192,  209,  223,  229,  861,  861,  448,
      224,  861,    0,  235,    0,    0,  179,  252,  861,    0,
      431,  861,  861,  861,  430,    0,    0,  861,  206,  210,
      257,  400,  389,    0,  413,    0,  413,  204,  861,  389,

      861,  198,  861,  861,    0,    0,  368,  296,  329,  213,
      349,  251,  253,  268,  369,  271,  861,    0,  291,  274,
      302,  314,  336,  861,  861,    0,  244,  340,  344,  345,
      361,  346,  266,  361,  384,  318,  201,  338,    0,  401,
      355,   80,    0,  299,  312,  306,  313,  297,  431,  464,
      484,  390,  308,  290,  297,  236,  392,  420,  517,  550,
      442,  583,  386,    0,  302,  262,  385,  424,  193,  603,
      624,  861,  449,  473,  208,  861,  453,  207,  495,  502,
      657,  480,  520,  528,  421,  189,  690,  414,  861,  506,
      539,  408,  545,  561,  572,  431,  102,  442,   44,  861,

      861,  724,  732,  740,  747,  755,  757,  760,  764,  772,
      780,  783,  787,  795,  803,  806,  808,  810,  812,  816,
      820,  828,  836,  844,  852
    } ;

static yyconst flex_int16_t yy_def[226] =
    {   0,
      201,    1,  201,    3,  202,  202,    3,    7,  203,  203,
        3,   11,  201,  201,  201,  201,  201,  201,  204,  201,
      205,  201,  201,  206,  201,  201,  201,  201,  201,   29,
      201,  201,  201,  207,  208,  201,  201,  201,  209,  210,
      210,  211,  201,  201,  201,  201,  201,  201,  212,  201,
      201,  201,  201,  204,  201,  204,  205,  213,  201,  201,
      206,  206,  201,   62,  206,   62,  214,  201,  201,  201,
      201,  201,  215,  201,   29,   30,  201,  201,  201,  216,
      201,  201,  201,  201,  201,  217,  208,  201,  201,  201,
      201,  201,  201,  218,  209,  210,  210,  211,  201,  211,

      201,  201,  201,  201,  212,  219,  213,  206,   62,  108,
       62,  206,  206,  206,  108,  214,  201,  215,  201,  201,
      201,  201,  216,  201,  201,  217,  201,  201,  201,  201,
      220,  221,  109,  206,  109,  108,  111,  111,  115,  201,
      201,  123,  123,  201,  201,  201,  220,  221,  108,  111,
      108,  111,  123,  222,  201,  201,  150,  111,  150,  108,
      111,  111,  123,  123,  222,  223,  222,  201,  201,  108,
      170,  201,  170,  111,  223,  201,  201,  201,  171,  111,
      171,  170,  111,  170,  201,  201,  170,  206,  201,  187,
      111,  224,  187,  111,  187,  224,  225,  224,  225,  201,

        0,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201
    } ;

static yyconst flex_int16_t yy_nxt[904] =
    {   0,
       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   20,   22,   25,   26,   27,   28,   29,   30,   30,
       30,   31,   32,   33,   34,   35,   35,   35,   35,   35,
       35,   14,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   36,   37,   41,   16,   17,  200,   38,   14,   15,
       16,   17,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   39,   39,   39,   39,   39,   39,   14,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   14,
       41,   16,   17,   42,   44,   45,   46,   44,   45,   46,

       51,   52,   68,  201,  200,   47,  153,  201,   47,   48,
       80,   59,   48,   14,   14,   14,   14,   14,   14,   55,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   49,
       49,   49,   49,   49,   49,   60,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   56,   69,   72,   59,   62,
       99,   73,   81,   82,   59,   84,   85,   59,   63,   59,
       63,   64,   64,   65,   91,   66,   66,   66,   66,   70,
       89,   71,   71,   71,   71,   90,  100,   55,   88,   67,
       74,   67,   75,   76,   76,   76,  101,  102,   51,   52,
      186,   77,   78,   61,   79,   80,  120,  120,   78,   92,

      101,  102,   93,   56,   62,   61,   61,   89,  186,   99,
      176,  127,   90,   63,   61,   61,   64,   64,   65,   63,
       66,   66,   66,   66,  109,  178,  108,  108,  108,  108,
      136,  136,  136,  136,   67,  100,   61,   61,  110,  113,
       67,   71,   71,   71,   71,  127,  114,  114,  114,   93,
      111,   78,  119,  119,  119,  119,  111,   78,   91,  115,
      116,   63,   78,   63,  176,  121,  121,   61,   78,  122,
      122,  122,  122,  169,  128,  128,  128,  128,   63,   61,
       61,  113,   67,   93,   67,  114,  114,  114,  114,  114,
      114,  140,  141,  141,  141,  166,   93,  109,  168,   67,

      144,  115,  116,   79,  154,  167,   63,  166,  119,  119,
      119,  119,  106,  108,  108,  108,  108,  167,   78,  122,
      122,  122,  122,  111,   78,  163,  164,   67,   94,  111,
      109,  122,  122,  122,  122,  136,  136,  136,  136,  109,
      156,  144,  133,  133,  134,  155,  135,  135,  135,  135,
       61,   61,   61,  142,  143,  143,  143,  128,  128,  128,
      128,  106,  137,  137,   61,   79,  138,  138,  138,  138,
       61,   63,  140,  141,  141,  141,   94,  146,  149,  149,
      149,  149,  145,  106,   79,  150,  139,  139,  139,  139,
      166,  201,   67,   61,  139,  139,  139,   61,   61,  151,

      167,  139,  139,  161,  161,   61,   61,  162,  162,  162,
      162,  152,  153,  197,   97,  188,   80,  152,  140,  141,
      141,  141,  185,  198,  189,  168,  192,   77,   94,  130,
       79,   80,  150,   61,   61,  129,  197,  170,  170,  170,
      170,  177,  177,  177,  177,   67,  198,  197,  149,  149,
      149,  149,  125,  124,  185,   61,   61,  198,  152,  162,
      162,  162,  162,  117,  152,  150,  182,  182,  182,  182,
      177,  177,  177,  177,  106,   57,  201,  157,  157,  158,
       50,  159,  159,  159,  159,  150,  183,  183,  104,  103,
      184,  184,  184,  184,   50,   97,   61,  182,  182,  182,

      182,  160,  160,  160,  160,   63,   94,   83,   61,   61,
       59,  152,   57,   53,   50,   61,   61,  152,  171,  187,
      187,  187,  187,  193,  193,  193,  193,  172,  201,  201,
       61,   61,  173,   61,   61,  201,  201,  184,  184,  184,
      184,  201,  201,  201,  174,  184,  184,  184,  184,  201,
      174,  150,  194,  194,  201,   61,  195,  195,  195,  195,
      201,   61,  193,  193,  193,  193,  201,  160,  160,  160,
      160,  201,  201,  201,   61,   61,  201,  152,  195,  195,
      195,  195,  201,  152,  150,  201,  201,  201,  201,  195,
      195,  195,  195,  201,  201,  201,   61,   61,  201,   61,

      162,  162,  162,  162,  171,   61,  201,  201,  201,  201,
      201,  201,  201,  172,  201,  201,  201,  201,  201,  201,
      170,  170,  170,  170,  201,  201,  201,  201,  201,  201,
      174,  201,  201,  201,  201,  201,  174,  179,  179,  180,
      201,  181,  181,  181,  181,  201,  201,  201,  201,  201,
      201,   61,  201,  201,  201,  201,  201,   61,  188,  201,
      201,  201,  201,  201,  201,  201,  201,  189,  201,  201,
       61,   61,  190,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  191,  201,  201,  201,  201,  201,
      191,  188,  201,  201,  201,  201,  201,  201,  201,  201,

      189,  201,  201,  201,  201,  201,  201,  187,  187,  187,
      187,  201,  201,  201,  201,  201,  201,  191,  201,  201,
      201,  201,  201,  191,   40,   40,   40,   40,   40,   40,
       40,   40,   43,   43,   43,   43,   43,   43,   43,   43,
       54,   54,   54,   54,   54,   54,   54,   54,   58,  201,
      201,  201,  201,   58,   58,   61,   61,  201,  201,   61,
       61,   61,   61,   86,   86,   87,   87,   87,   95,   95,
       95,   95,   96,   96,  201,  201,   96,   96,   96,   96,
       98,   98,   98,   98,   98,   98,   98,   98,  105,  105,
      105,  107,  107,  107,  107,  112,  112,  201,  201,  112,

      112,  112,  112,  118,  118,  201,  118,  118,  118,  118,
      118,  123,  123,  126,  126,  126,  131,  131,  132,  132,
      147,  147,  147,  147,  148,  148,  148,  148,  165,  165,
      201,  165,  165,  165,  165,  165,  175,  175,  175,  175,
      175,  175,  175,  175,  196,  196,  201,  196,  196,  196,
      196,  196,  199,  199,  199,  199,  199,  199,  199,  199,
       13,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,

      201,  201,  201
    } ;

static yyconst flex_int16_t yy_chk[904] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    2,    5,    5,    5,  199,    2,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        6,    6,    6,    7,    9,    9,    9,   10,   10,   10,

       17,   17,   25,   30,  197,    9,  142,   30,   10,    9,
      142,   25,   10,    7,    7,    7,    7,    7,    7,   19,
        7,    7,    7,    7,    7,    7,    7,    7,    7,   11,
       11,   11,   11,   11,   11,   23,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   19,   26,   28,   23,   24,
       42,   28,   31,   31,   26,   33,   33,   28,   24,   36,
       61,   24,   24,   24,   38,   24,   24,   24,   24,   27,
       37,   27,   27,   27,   27,   37,   42,   54,   36,   24,
       29,   61,   29,   29,   29,   29,   46,   46,   52,   52,
      186,   29,   29,   64,   29,   29,   77,   77,   29,   38,

      102,  102,   38,   54,   62,   64,   64,   89,  178,   98,
      175,   90,   89,   62,  137,  137,   62,   62,   62,   65,
       62,   62,   62,   62,   66,  169,   65,   65,   65,   65,
      110,  110,  110,  110,   62,   98,   66,   66,   66,   67,
       65,   71,   71,   71,   71,  127,   67,   67,   67,   90,
       66,   71,   74,   74,   74,   74,   66,   71,   91,   67,
       67,  112,   74,  113,  166,   78,   78,  133,   74,   78,
       78,   78,   78,  156,   91,   91,   91,   91,  114,  133,
      133,  116,  112,  127,  113,  114,  114,  114,  116,  116,
      116,  120,  120,  120,  120,  154,   91,  108,  155,  114,

      144,  116,  116,  120,  144,  154,  108,  165,  119,  119,
      119,  119,  148,  108,  108,  108,  108,  165,  119,  121,
      121,  121,  121,  108,  119,  153,  153,  108,  147,  108,
      109,  122,  122,  122,  122,  136,  136,  136,  136,  138,
      146,  128,  109,  109,  109,  145,  109,  109,  109,  109,
      111,  138,  138,  123,  123,  123,  123,  128,  128,  128,
      128,  132,  111,  111,  111,  123,  111,  111,  111,  111,
      115,  134,  141,  141,  141,  141,  131,  130,  134,  134,
      134,  134,  129,  107,  141,  135,  115,  115,  115,  115,
      167,  100,  134,  157,  115,  115,  115,  135,  135,  135,

      167,  115,  115,  152,  152,  157,  157,  152,  152,  152,
      152,  135,  163,  192,   97,  188,  163,  135,  140,  140,
      140,  140,  185,  192,  188,  168,  185,  140,   95,   93,
      140,  140,  149,  158,  158,   92,  196,  158,  158,  158,
      158,  168,  168,  168,  168,  188,  196,  198,  149,  149,
      149,  149,   85,   81,  177,  161,  161,  198,  149,  161,
      161,  161,  161,   70,  149,  150,  173,  173,  173,  173,
      177,  177,  177,  177,   58,   57,   56,  150,  150,  150,
       50,  150,  150,  150,  150,  151,  174,  174,   48,   47,
      174,  174,  174,  174,   44,   41,  179,  182,  182,  182,

      182,  151,  151,  151,  151,  179,   39,   32,  179,  179,
       22,  151,   21,   18,   15,  180,  180,  151,  159,  180,
      180,  180,  180,  190,  190,  190,  190,  159,   13,    0,
      159,  159,  159,  183,  183,    0,    0,  183,  183,  183,
      183,    0,    0,    0,  159,  184,  184,  184,  184,    0,
      159,  160,  191,  191,    0,  184,  191,  191,  191,  191,
        0,  184,  193,  193,  193,  193,    0,  160,  160,  160,
      160,    0,    0,    0,  194,  194,    0,  160,  194,  194,
      194,  194,    0,  160,  162,    0,    0,    0,    0,  195,
      195,  195,  195,    0,    0,    0,  162,  162,    0,  195,

      162,  162,  162,  162,  170,  195,    0,    0,    0,    0,
        0,    0,    0,  170,    0,    0,    0,    0,    0,    0,
      170,  170,  170,  170,    0,    0,    0,    0,    0,    0,
      170,    0,    0,    0,    0,    0,  170,  171,  171,  171,
        0,  171,  171,  171,  171,    0,    0,    0,    0,    0,
        0,  171,    0,    0,    0,    0,    0,  171,  181,    0,
        0,    0,    0,    0,    0,    0,    0,  181,    0,    0,
      181,  181,  181,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  181,    0,    0,    0,    0,    0,
      181,  187,    0,    0,    0,    0,    0,    0,    0,    0,

      187,    0,    0,    0,    0,    0,    0,  187,  187,  187,
      187,    0,    0,    0,    0,    0,    0,  187,    0,    0,
        0,    0,    0,  187,  202,  202,  202,  202,  202,  202,
      202,  202,  203,  203,  203,  203,  203,  203,  203,  203,
      204,  204,  204,  204,  204,  204,  204,  204,  205,    0,
        0,    0,    0,  205,  205,  206,  206,    0,    0,  206,
      206,  206,  206,  207,  207,  208,  208,  208,  209,  209,
      209,  209,  210,  210,    0,    0,  210,  210,  210,  210,
      211,  211,  211,  211,  211,  211,  211,  211,  212,  212,
      212,  213,  213,  213,  213,  214,  214,    0,    0,  214,

      214,  214,  214,  215,  215,    0,  215,  215,  215,  215,
      215,  216,  216,  217,  217,  217,  218,  218,  219,  219,
      220,  220,  220,  220,  221,  221,  221,  221,  222,  222,
        0,  222,  222,  222,  222,  222,  223,  223,  223,  223,
      223,  223,  223,  223,  224,  224,    0,  224,  224,  224,
      224,  224,  225,  225,  225,  225,  225,  225,  225,  225,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,

      201,  201,  201
    } ;

extern int qc_yy_flex_debug;
int qc_yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up qc_yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *qc_yytext;
#line 1 "../../../../tools/qfcc/source/qc-lex.l"
#line 2 "../../../../tools/qfcc/source/qc-lex.l"
/*
	qc-lex.l

	lexer for quakec

	Copyright (C) 2001 Bill Currie <bill@taniwha.org>

	Author: Bill Currie <bill@taniwha.org>
	Date: 2001/06/12

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

	See the GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to:

		Free Software Foundation, Inc.
		59 Temple Place - Suite 330
		Boston, MA  02111-1307, USA

*/
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#ifdef HAVE_STRING_H
# include <string.h>
#endif
#ifdef HAVE_STRINGS_H
# include <strings.h>
#endif
#include <stdlib.h>
#include <ctype.h>

#include <QF/dstring.h>
#include <QF/hash.h>
#include <QF/sys.h>

#include "class.h"
#include "debug.h"
#include "diagnostic.h"
#include "expr.h"
#include "grab.h"
#include "options.h"
#include "pragma.h"
#include "qfcc.h"
#include "shared.h"
#include "strpool.h"
#include "struct.h"
#include "symtab.h"
#include "type.h"
#include "value.h"

#include "qc-parse.h"

#ifndef YY_PROTO
# define YY_PROTO(x) x
#else
# define YY_FLEX_REALLOC_HACK
#endif

#define YY_NO_UNPUT
#define YY_DECL int qc_yylex YY_PROTO(( void ))
YY_DECL;


static int keyword_or_id (char *token);

extern QC_YYSTYPE qc_yylval;


#line 858 "qc-lex.c"

#define INITIAL 0
#define GRAB_FRAME 1
#define GRAB_OTHER 2
#define GRAB_WRITE 3
#define COMMENT 4
#define PRAGMA 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int qc_yylex_destroy (void );

int qc_yyget_debug (void );

void qc_yyset_debug (int debug_flag  );

YY_EXTRA_TYPE qc_yyget_extra (void );

void qc_yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *qc_yyget_in (void );

void qc_yyset_in  (FILE * in_str  );

FILE *qc_yyget_out (void );

void qc_yyset_out  (FILE * out_str  );

int qc_yyget_leng (void );

char *qc_yyget_text (void );

int qc_yyget_lineno (void );

void qc_yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int qc_yywrap (void );
#else
extern int qc_yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( qc_yytext, qc_yyleng, 1, qc_yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( qc_yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( qc_yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, qc_yyin))==0 && ferror(qc_yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(qc_yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int qc_yylex (void);

#define YY_DECL int qc_yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after qc_yytext and qc_yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( qc_yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(qc_yytext[qc_yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 98 "../../../../tools/qfcc/source/qc-lex.l"

					grab_frame = GRAB_FRAME;
					grab_other = GRAB_OTHER;
					grab_write = GRAB_WRITE;

#line 1059 "qc-lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)qc_yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in qc_yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! qc_yyin )
			qc_yyin = stdin;

		if ( ! qc_yyout )
			qc_yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			qc_yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				qc_yy_create_buffer(qc_yyin,YY_BUF_SIZE );
		}

		qc_yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of qc_yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 202 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 861 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 103 "../../../../tools/qfcc/source/qc-lex.l"
{ BEGIN (COMMENT); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 104 "../../../../tools/qfcc/source/qc-lex.l"
{ warning (0, "nested /* in comment"); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 105 "../../../../tools/qfcc/source/qc-lex.l"
{ BEGIN (INITIAL); }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 106 "../../../../tools/qfcc/source/qc-lex.l"
{ pr.source_line++; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 107 "../../../../tools/qfcc/source/qc-lex.l"
/* nothing to do */
	YY_BREAK
case YY_STATE_EOF(COMMENT):
#line 108 "../../../../tools/qfcc/source/qc-lex.l"
{ error (0, "EOF in comment"); return 0; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 109 "../../../../tools/qfcc/source/qc-lex.l"
/* nothing to do */
	YY_BREAK
case 7:
*yy_cp = (yy_hold_char); /* undo effects of setting up qc_yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up qc_yytext again */
YY_RULE_SETUP
#line 111 "../../../../tools/qfcc/source/qc-lex.l"
{ line_info (qc_yytext + 1); }
	YY_BREAK
case 8:
*yy_cp = (yy_hold_char); /* undo effects of setting up qc_yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up qc_yytext again */
YY_RULE_SETUP
#line 112 "../../../../tools/qfcc/source/qc-lex.l"
{ line_info (qc_yytext + 5); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 114 "../../../../tools/qfcc/source/qc-lex.l"
{ BEGIN (PRAGMA); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 116 "../../../../tools/qfcc/source/qc-lex.l"
{
						const char *c = qc_yytext + qc_yyleng - 1;
						int         i;

						if (qc_yytext[0] == '0' && tolower (qc_yytext[1] == 'b'))
							i = strtol (qc_yytext + 2, 0, 2);
						else
							i = strtol (qc_yytext, 0, 0);
						if (*c == 'u' || *c == 'U')
							qc_yylval.expr = new_integer_expr (i);//FIXME
						else
							qc_yylval.expr = new_integer_expr (i);
						return VALUE;
					}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 131 "../../../../tools/qfcc/source/qc-lex.l"
{
						float       f = strtof (qc_yytext, 0);
						qc_yylval.expr = new_float_expr (f);
						return VALUE;
					}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 137 "../../../../tools/qfcc/source/qc-lex.l"
{
						int         tok = keyword_or_id(qc_yytext);
						return tok;
					}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 141 "../../../../tools/qfcc/source/qc-lex.l"
{
						int         tok = keyword_or_id(qc_yytext);
						if (tok == '@')
							REJECT;
						return tok;
					}
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 148 "../../../../tools/qfcc/source/qc-lex.l"
{
						const char *s = make_string (qc_yytext, 0);
						qc_yylval.expr = new_string_expr (s);
						return STRING;
					}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 153 "../../../../tools/qfcc/source/qc-lex.l"
return '@';
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 155 "../../../../tools/qfcc/source/qc-lex.l"
{
						vec3_t      v;
						sscanf (qc_yytext, "' %f %f %f '",
								&v[0], &v[1], &v[2]);
						qc_yylval.expr = new_vector_expr (v);
						return VALUE;
					}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 163 "../../../../tools/qfcc/source/qc-lex.l"
{
						quat_t      q;
						sscanf (qc_yytext, "' %f %f %f %f'",
								&q[0], &q[1], &q[2], &q[3]);
						qc_yylval.expr = new_quaternion_expr (q);
						return VALUE;
					}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 171 "../../../../tools/qfcc/source/qc-lex.l"
{
						const char *str = make_string (qc_yytext, 0);

						if (str[1])
							warning (0, "multibyte char constant");
						qc_yylval.expr = new_integer_expr (*str);
						return VALUE;
					}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 180 "../../../../tools/qfcc/source/qc-lex.l"
{
						qc_yylval.op = qc_yytext[0];
						return ASX;
					}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 185 "../../../../tools/qfcc/source/qc-lex.l"
{
						qc_yylval.op = SHL;
						return ASX;
					}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 190 "../../../../tools/qfcc/source/qc-lex.l"
{
						qc_yylval.op = SHR;
						return ASX;
					}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 195 "../../../../tools/qfcc/source/qc-lex.l"
{
						qc_yylval.pointer = 0;	// ensure pointer vals are null
						return qc_yytext[0];
					}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 200 "../../../../tools/qfcc/source/qc-lex.l"
return ELLIPSIS;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 202 "../../../../tools/qfcc/source/qc-lex.l"
return SHL;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 203 "../../../../tools/qfcc/source/qc-lex.l"
return SHR;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 205 "../../../../tools/qfcc/source/qc-lex.l"
return AND;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 206 "../../../../tools/qfcc/source/qc-lex.l"
return OR;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 207 "../../../../tools/qfcc/source/qc-lex.l"
return EQ;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 208 "../../../../tools/qfcc/source/qc-lex.l"
return NE;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 209 "../../../../tools/qfcc/source/qc-lex.l"
return LE;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 210 "../../../../tools/qfcc/source/qc-lex.l"
return GE;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 211 "../../../../tools/qfcc/source/qc-lex.l"
return LT;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 212 "../../../../tools/qfcc/source/qc-lex.l"
return GT;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 214 "../../../../tools/qfcc/source/qc-lex.l"
{
						qc_yylval.op = '+';
						return INCOP;
					}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 219 "../../../../tools/qfcc/source/qc-lex.l"
{
						qc_yylval.op = '-';
						return INCOP;
					}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 224 "../../../../tools/qfcc/source/qc-lex.l"
{
						int ret = do_grab (qc_yytext);
						if (ret >= 0) {
							qc_yylval.expr = new_integer_expr (ret);
							return VALUE;
						} else {
							BEGIN (-ret);
						}
					}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 234 "../../../../tools/qfcc/source/qc-lex.l"
add_frame_macro (qc_yytext);
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 235 "../../../../tools/qfcc/source/qc-lex.l"
/* skip */
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 236 "../../../../tools/qfcc/source/qc-lex.l"
{
							const char *s = make_string (qc_yytext, 0);
							write_frame_macros (s);
							BEGIN (GRAB_OTHER);	// ignore rest of line
						}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 241 "../../../../tools/qfcc/source/qc-lex.l"
{ pragma (qc_yytext); }
	YY_BREAK
case 41:
/* rule 41 can match eol */
YY_RULE_SETUP
#line 243 "../../../../tools/qfcc/source/qc-lex.l"
{
						pr.source_line++;
						BEGIN (INITIAL);
					}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 248 "../../../../tools/qfcc/source/qc-lex.l"
/* skip */
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 250 "../../../../tools/qfcc/source/qc-lex.l"
error (0, "all your typo are belong to us");
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 252 "../../../../tools/qfcc/source/qc-lex.l"
ECHO;
	YY_BREAK
#line 1467 "qc-lex.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(GRAB_FRAME):
			case YY_STATE_EOF(GRAB_OTHER):
			case YY_STATE_EOF(GRAB_WRITE):
			case YY_STATE_EOF(PRAGMA):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed qc_yyin at a new source and called
			 * qc_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = qc_yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( qc_yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * qc_yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of qc_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			qc_yyrestart(qc_yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) qc_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 202 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 202 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 201);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up qc_yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					qc_yyrestart(qc_yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( qc_yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve qc_yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void qc_yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        qc_yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            qc_yy_create_buffer(qc_yyin,YY_BUF_SIZE );
	}

	qc_yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	qc_yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void qc_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		qc_yypop_buffer_state();
	 *		qc_yypush_buffer_state(new_buffer);
     */
	qc_yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	qc_yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (qc_yywrap()) processing, but the only time this flag
	 * is looked at is after qc_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void qc_yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	qc_yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE qc_yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) qc_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in qc_yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) qc_yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in qc_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	qc_yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with qc_yy_create_buffer()
 * 
 */
    void qc_yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		qc_yyfree((void *) b->yy_ch_buf  );

	qc_yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a qc_yyrestart() or at EOF.
 */
    static void qc_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	qc_yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then qc_yy_init_buffer was _probably_
     * called from qc_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void qc_yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		qc_yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void qc_yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	qc_yyensure_buffer_stack();

	/* This block is copied from qc_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from qc_yy_switch_to_buffer. */
	qc_yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void qc_yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	qc_yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		qc_yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void qc_yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)qc_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in qc_yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)qc_yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in qc_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE qc_yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) qc_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in qc_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	qc_yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to qc_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       qc_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE qc_yy_scan_string (yyconst char * yystr )
{
    
	return qc_yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to qc_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE qc_yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) qc_yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in qc_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = qc_yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in qc_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up qc_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		qc_yytext[qc_yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = qc_yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		qc_yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int qc_yyget_lineno  (void)
{
        
    return qc_yylineno;
}

/** Get the input stream.
 * 
 */
FILE *qc_yyget_in  (void)
{
        return qc_yyin;
}

/** Get the output stream.
 * 
 */
FILE *qc_yyget_out  (void)
{
        return qc_yyout;
}

/** Get the length of the current token.
 * 
 */
int qc_yyget_leng  (void)
{
        return qc_yyleng;
}

/** Get the current token.
 * 
 */

char *qc_yyget_text  (void)
{
        return qc_yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void qc_yyset_lineno (int  line_number )
{
    
    qc_yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see qc_yy_switch_to_buffer
 */
void qc_yyset_in (FILE *  in_str )
{
        qc_yyin = in_str ;
}

void qc_yyset_out (FILE *  out_str )
{
        qc_yyout = out_str ;
}

int qc_yyget_debug  (void)
{
        return qc_yy_flex_debug;
}

void qc_yyset_debug (int  bdebug )
{
        qc_yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from qc_yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    qc_yyin = stdin;
    qc_yyout = stdout;
#else
    qc_yyin = (FILE *) 0;
    qc_yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * qc_yylex_init()
     */
    return 0;
}

/* qc_yylex_destroy is for both reentrant and non-reentrant scanners. */
int qc_yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		qc_yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		qc_yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	qc_yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    qc_yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * qc_yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *qc_yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *qc_yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void qc_yyfree (void * ptr )
{
	free( (char *) ptr );	/* see qc_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 252 "../../../../tools/qfcc/source/qc-lex.l"



int
qc_yywrap (void)
{
	return 1;
}

typedef struct {
	const char *name;
	int         value;
	type_t     *type;
} keyword_t;

// These keywords are all part of the Ruamoko (Objective-QC) language.
// The first time any one of them is encountered, the class system will be
// initialized.
// If not compiling for the QuakeForge VM, or if Ruamoko has been disabled,
// then they will be unavailable as keywords.
static keyword_t obj_keywords[] = {
	{"id",				OBJECT,	&type_id		},
	{"Class",			TYPE,	&type_Class		},
	{"Method",			TYPE,	&type_obj_method},
	{"Super",			TYPE,	&type_obj_super	},
	{"SEL",				TYPE,	&type_SEL		},
	{"IMP",				TYPE,	&type_IMP		},

	{"@class",			CLASS					},
	{"@defs",			DEFS					},
	{"@encode",			ENCODE					},
	{"@end",			END						},
	{"@implementation",	IMPLEMENTATION			},
	{"@interface",		INTERFACE				},
	{"@private",		PRIVATE					},
	{"@protected",		PROTECTED				},
	{"@protocol",		PROTOCOL				},
	{"@public",			PUBLIC					},
	{"@reference",		REFERENCE				},
	{"@selector",		SELECTOR				},
	{"@self",			SELF					},
	{"@this",			THIS					},

	// This is a hack to trigger the initialization of the class
	// sytem if it is seen before any other Objective-QC symbol. Otherwise,
	// it is just an identifier, though it does reference a built-in type
	// created by the class system.
	{"obj_module",		0						},
};

// These keywords are extensions to QC and thus available only in advanced
// or extended code. However, if they are preceeded by an @ (eg, @for), then
// they are always available. This is to prevent them from causing trouble
// for traditional code that might use these words as identifiers, but still
// make the language features available to traditional code.
static keyword_t at_keywords[] = {
	{"for",			FOR		},
	{"break",		BREAK	},
	{"continue",	CONTINUE},
	{"switch",		SWITCH	},
	{"case",		CASE	},
	{"default",		DEFAULT	},
	{"nil",			NIL		},
	{"struct",		STRUCT	},
	{"union",		STRUCT	},
	{"enum",		ENUM	},
	{"typedef",		TYPEDEF	},
	{"extern",		EXTERN	},
	{"static",		STATIC	},
	{"sizeof",		SIZEOF	},
	{"nosave",		NOSAVE	},
};

// These keywords require the QuakeForge VM to be of any use. ie, they cannot
// be supported (sanely) by v6 progs.
static keyword_t qf_keywords[] = {
	{"quaternion",	TYPE,	&type_quaternion},
	{"int",			TYPE,	&type_integer	},
	{"unsigned",	TYPE,	&type_integer	},//FIXME
	{"function",	TYPE,	&type_function	},

	{"@args",		ARGS,	0				},
	{"@va_list",	TYPE,	&type_va_list	},
	{"@param",		TYPE,	&type_param		},
};

// These keywors are always available. Other than @system and @overload, they
// form traditional QuakeC.
static keyword_t keywords[] = {
	{"void",		TYPE,		&type_void	},
	{"float",		TYPE,		&type_float	},
	{"string",		TYPE,		&type_string},
	{"vector",		TYPE,		&type_vector},
	{"entity",		TYPE,		&type_entity},
	{"local",		LOCAL,		0			},
	{"return",		RETURN,		0			},
	{"while",		WHILE,		0			},
	{"do",			DO,			0			},
	{"if",			IF,			0			},
	{"else",		ELSE,		0			},
	{"@system",		SYSTEM,		0			},
	{"@overload",	OVERLOAD,	0			},
};

static const char *
keyword_get_key (const void *kw, void *unused)
{
	return ((keyword_t*)kw)->name;
}

static int
process_keyword (keyword_t *keyword, const char *token)
{
	if (keyword->value == STRUCT) {
		qc_yylval.op = token[0];
	} else if (keyword->value == OBJECT) {
		symbol_t   *sym;

		sym = symtab_lookup (current_symtab, token);
		qc_yylval.symbol = sym;
	} else {
		qc_yylval.type = keyword->type;
	}
	return keyword->value;
}

static int
keyword_or_id (char *token)
{
	static hashtab_t *keyword_tab;
	static hashtab_t *qf_keyword_tab;
	static hashtab_t *at_keyword_tab;
	static hashtab_t *obj_keyword_tab;

	keyword_t  *keyword = 0;
	symbol_t   *sym;

	if (!keyword_tab) {
		size_t      i;

		keyword_tab = Hash_NewTable (253, keyword_get_key, 0, 0);
		qf_keyword_tab = Hash_NewTable (253, keyword_get_key, 0, 0);
		at_keyword_tab = Hash_NewTable (253, keyword_get_key, 0, 0);
		obj_keyword_tab = Hash_NewTable (253, keyword_get_key, 0, 0);

		#define NUMKEYS(_k) (sizeof (_k) / sizeof (_k[0]))

		for (i = 0; i < NUMKEYS(keywords); i++)
			Hash_Add (keyword_tab, &keywords[i]);
		for (i = 0; i < NUMKEYS(qf_keywords); i++)
			Hash_Add (qf_keyword_tab, &qf_keywords[i]);
		for (i = 0; i < NUMKEYS(at_keywords); i++)
			Hash_Add (at_keyword_tab, &at_keywords[i]);
		for (i = 0; i < NUMKEYS(obj_keywords); i++)
			Hash_Add (obj_keyword_tab, &obj_keywords[i]);
	}
	if (options.traditional < 1) {
		keyword = Hash_Find (obj_keyword_tab, token);
		if (keyword) {
			if (!obj_initialized)
				class_init ();
		}
		if (!keyword)
			keyword = Hash_Find (qf_keyword_tab, token);
	}
	if (!keyword && options.traditional < 2)
		keyword = Hash_Find (at_keyword_tab, token);
	if (!keyword && token[0] == '@') {
		keyword = Hash_Find (at_keyword_tab, token + 1);
		if (keyword)
			token += 1;
	}
	if (!keyword)
		keyword = Hash_Find (keyword_tab, token);
	if (keyword && keyword->value)
		return process_keyword (keyword, token);
	if (token[0] == '@') {
		return '@';
	}
	sym = symtab_lookup (current_symtab, token);
	if (!sym)
		sym = new_symbol (token);
	qc_yylval.symbol = sym;
	if (sym->sy_type == sy_type)
		return TYPE_NAME;
	if (sym->sy_type == sy_class)
		return CLASS_NAME;
	return NAME;
}

#ifdef YY_FLEX_REALLOC_HACK
static __attribute__ ((used)) void *(*const yy_flex_realloc_hack)(void *,yy_size_t) = yy_flex_realloc;
#else
static __attribute__ ((used)) void (*yyunput_hack)(int, char*) = yyunput;
static __attribute__ ((used)) int (*input_hack)(void) = input;
#endif

